==> haskell-wai-extra-3.1.17-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-extra
version:              3.1.17
visibility:           public
id:                   wai-extra-3.1.17-8YgjU15N6oKKg25qYeS49N
key:                  wai-extra-3.1.17-8YgjU15N6oKKg25qYeS49N
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * Combine Headers

    Combine duplicate headers into one.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * Health check endpoint

    Add an empty health check endpoint.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Select

    Dynamically choose between Middlewares.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  33c90f2582779b85a89a86072cf23ab4
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.CombineHeaders
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip
    Network.Wai.Middleware.HealthCheckEndpoint
    Network.Wai.Middleware.HttpAuth Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.Local Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RealIp Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.Select Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.ValidateHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:
    Network.Wai.Middleware.RequestLogger.Internal Network.Wai.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-extra
hs-libraries:         HSwai-extra-3.1.17-8YgjU15N6oKKg25qYeS49N
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    aeson-2.1.2.1-F8ZePgr6g4xL6kF4wsQx0x
    ansi-terminal-1.0.2-vFVvoY6zrCCEYOqozRT68 base-4.17.2.1
    base64-bytestring-1.2.1.0-BuaE7coGml7AORbY2RxXh2
    bytestring-0.11.5.3 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    case-insensitive-1.2.1.0-B227KtiOix4GTDgvxk3FBB containers-0.6.7
    cookie-0.4.6-4shfaVKBFn0Hnep1ZY6FZw
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM directory-1.3.7.1
    fast-logger-3.2.4-IT6osmo3AQ0I0WQWWMpdku
    http-types-0.12.4-Hsb6Y5xUgLKEUlBrgYk3WM
    iproute-1.7.15-FSuDobGJskULwUB4yHN9ir
    network-3.1.4.0-7GxbLibXQB6BN49yptQL65
    resourcet-1.2.6-1uUyorfyzWb8h78koH6NVM
    streaming-commons-0.2.3.0-3D1MsoYRsMeH2GPkEp5d7R text-2.0.2
    time-1.12.2 transformers-0.5.6.2 unix-2.7.3
    vault-0.3.1.5-IVkO043ANT2A8k5qB0IpqA
    wai-3.2.4-4xRq7ogBaZ8Gldz3i6sILu
    wai-logger-2.5.0-LGHK8YVG51EAqGzYQj5bEc
    warp-3.3.30-AhKrB9wwsoN3qw8940l6Mi
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.1.17-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-extra
version:              3.1.17
visibility:           public
id:                   wai-extra-3.1.17-LNZKSRSoPdF14IlWcRuLur
key:                  wai-extra-3.1.17-LNZKSRSoPdF14IlWcRuLur
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * Combine Headers

    Combine duplicate headers into one.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * Health check endpoint

    Add an empty health check endpoint.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Select

    Dynamically choose between Middlewares.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  9a75f6775f9689c65d1ed7d97d7f2808
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.CombineHeaders
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip
    Network.Wai.Middleware.HealthCheckEndpoint
    Network.Wai.Middleware.HttpAuth Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.Local Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RealIp Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.Select Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.ValidateHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:
    Network.Wai.Middleware.RequestLogger.Internal Network.Wai.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-extra
hs-libraries:         HSwai-extra-3.1.17-LNZKSRSoPdF14IlWcRuLur
depends:
    HUnit-1.6.2.0-9X1R1uFIABDFmOEozkgarM
    aeson-2.1.2.1-IZ8jLcnEISD7S5Vyf2Tehm
    ansi-terminal-1.0.2-FTkVGNDxEfy5jKOkYDwQmU base-4.17.2.1
    base64-bytestring-1.2.1.0-7CU13IWnWdcDMU9nDc25iT
    bytestring-0.11.5.3 call-stack-0.4.0-wdz1639SOC9HqySMka9DA
    case-insensitive-1.2.1.0-3FuXchFPXBfLVJKu7fam1O containers-0.6.7
    cookie-0.4.6-4shfaVKBFn0Hnep1ZY6FZw
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM directory-1.3.7.1
    fast-logger-3.2.4-BO4Ac6rNDrh86XbYhPlfV7
    http-types-0.12.4-9GhteoJuOlZ3ATAYoIbhkU
    iproute-1.7.15-DgSqz1ZLAmiExFgSzxBywk
    network-3.1.4.0-KAEk2uZxmO9GA8hoXz0jL7
    resourcet-1.2.6-98QeMzdnC7kQabpsrpmbK
    streaming-commons-0.2.3.0-CvQm1m2y9fJH6ySXW21rvR text-2.0.2
    time-1.12.2 transformers-0.5.6.2 unix-2.7.3
    vault-0.3.1.5-6IncVOQOIZY1OTTZhdmRxQ
    wai-3.2.4-LSet4Oo8Svc8BhPeth6Bg
    wai-logger-2.5.0-8jkNTdYkzCP5zUgFiaHeA8
    warp-3.3.30-JYRa6G4TpFBCfP4ZSgWbtY
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
